package com.example.practika.view.components.mainActivity

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.ui.platform.LocalContext
import androidx.navigation.NavHostController
import com.example.practika.domain.utils.Constants
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.Alignment
import androidx.compose.ui.unit.sp
import org.w3c.dom.Text
import androidx.compose.material3.Text
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.RadioButton
import androidx.compose.runtime.MutableState
import io.github.jan.supabase.postgrest.from
import kotlinx.coroutines.launch
import com.example.practika.model.Songs

import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.ui.text.input.KeyboardType

@Composable
fun Option(navHost: NavHostController){
    val context = LocalContext.current
    val supabase = Constants.supabase
    val scope = rememberCoroutineScope()

    val Name = remember { mutableStateOf("") }
    val performerId = remember { mutableStateOf(0) }
    val genreId = remember { mutableStateOf(0) }
    val fotoUrl = remember { mutableStateOf("") }

    Column(
        modifier = Modifier
            .fillMaxWidth()
            .padding(top = 300.dp, start = 15.dp, end = 15.dp)

            .fillMaxWidth(),
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        TextField(
            value = Name.value,
            onValueChange = { Name.value = it },
            label = { Text("title", fontSize = 18.sp, color = Color.White) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = 16.dp)
                .background(Color.White, shape = RoundedCornerShape(8.dp))
                .border(width = 1.dp, color = Color.White, shape = RoundedCornerShape(8.dp))
        )
        Spacer(modifier = Modifier.height(8.dp))
        TextField(
            value = performerId.value.toString(),

            onValueChange = {
                if (it.all { char -> char.isDigit() }) {
                    performerId.value = it.toInt()
                }
            },
            label = { Text("Исполнитель", fontSize = 18.sp, color = Color.White) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = 16.dp)
                .background(Color.White, shape = RoundedCornerShape(8.dp))
                .border(width = 1.dp, color = Color.White, shape = RoundedCornerShape(8.dp)),
            keyboardOptions = KeyboardOptions.Default.copy(keyboardType = KeyboardType.Number)
        )
        Spacer(modifier = Modifier.height(8.dp))

        TextField(
            value = genreId.value.toString(),

            onValueChange = {
                if (it.all { char -> char.isDigit() }) {
                    genreId.value = it.toInt()
                }
            },
            label = { Text("Жанр", fontSize = 18.sp, color = Color.White) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = 16.dp)
                .background(Color.White, shape = RoundedCornerShape(8.dp))
                .border(width = 1.dp, color = Color.White, shape = RoundedCornerShape(8.dp)),
                    keyboardOptions = KeyboardOptions.Default.copy(keyboardType = KeyboardType.Number)
        )
        Spacer(modifier = Modifier.height(8.dp))

        TextField(
            value = fotoUrl.value,
            onValueChange = { fotoUrl.value = it },
            label = { Text("url", fontSize = 18.sp, color = Color.White) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = 16.dp)
                .background(Color.White, shape = RoundedCornerShape(8.dp))
                .border(width = 1.dp, color = Color.White, shape = RoundedCornerShape(8.dp))
        )
        Spacer(modifier = Modifier.height(16.dp))
        Button(onClick = {
            scope.launch {
                val count = supabase.from("Songs").select().data.count()
                val newSong = Songs(
                    id = count.toInt() + 1,
                    title_song = Name.value,
                    img = fotoUrl.value.ifBlank { null },
                    performer = performerId.value,
                    genre = genreId.value
                )
                supabase.from("Songs").insert(newSong)
            }
        })
        {
            Text("Добавить", fontSize = 25.sp, color = Color.White)
        }
        ButtonDefaults.buttonColors(Color.White)
    }
}

