package com.example.practika.view.components.mainActivity
import androidx.compose.foundation.Image
import android.util.Log
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.wrapContentSize
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import com.example.practika.domain.utils.Constants
import com.example.practika.model.Songs
import com.example.practika.model.Genres
import com.example.practika.model.Performers
import io.github.jan.supabase.storage.BucketItem
import io.github.jan.supabase.postgrest.from
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.Text
import androidx.compose.ui.unit.dp
import androidx.navigation.NavHostController
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import coil.compose.rememberAsyncImagePainter
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.geometry.Offset
import androidx.compose.ui.graphics.Brush
import androidx.compose.ui.layout.ContentScale
import coil.compose.AsyncImagePainter
import coil.request.ImageRequest
import coil.size.Size
import com.example.practika.model.Admin
import io.github.jan.supabase.gotrue.auth
import androidx.compose.material3.Button
import androidx.compose.ui.unit.sp
import io.github.jan.supabase.postgrest.from

import kotlinx.coroutines.withContext


@Composable
fun SongsList(navHost: NavHostController) {

    var genres by remember { mutableStateOf<List<Genres>>(listOf())}
    var performers by remember { mutableStateOf<List<Performers>>(listOf())}
    var users by remember { mutableStateOf<List<Admin>>(listOf()) }
    var bucket: ByteArray? = null
    var bytes:ByteArray? = null
    var files: List<BucketItem>? = null
    var songs by remember { mutableStateOf<List<Songs>>(listOf())}
        LaunchedEffect(Unit) {
        withContext(Dispatchers.IO) {
            songs = Constants.supabase.from("Songs")
                .select().decodeList<Songs>()
            genres = Constants.supabase.from("Genre")
                .select().decodeList<Genres>()
            performers = Constants.supabase.from("Performers")
                .select().decodeList<Performers>()
            users = Constants.supabase.from("Admin")
                .select().decodeList<Admin>()
            songs.forEach { it ->
                Log.d("ts", it.title_song)
            }
        }
    }
    Column(
        modifier = Modifier
            .fillMaxSize() // Fill the maximum size of the screen
            .wrapContentSize(Alignment.Center) // Center the content horizontally and vertically
            .padding(26.dp)
    ) {
        val userId = Constants.supabase.auth.currentUserOrNull()?.id
        val userIdString = userId.toString()
        if (userId != null) {
            val user = users.find { it.id_user == userIdString }
            if (user != null) {
                Button(onClick = {
                    navHost.navigate("Option")
                }) {
                    Text("Опции", fontSize = 25.sp, color = Color.White)
                }
            }
        }
        LazyColumn(

            modifier = Modifier
                .fillMaxSize() // Fill the maximum size of the screen
                .wrapContentSize(Alignment.Center) // Center the content horizontally and vertically
                .padding(16.dp)
        ) {

            items(
                songs,
                key = { song -> song.id },
            ) { song ->
                val imageState = rememberAsyncImagePainter(
                    model = ImageRequest.Builder(LocalContext.current).data(song.img)
                        .size(Size.ORIGINAL).build()
                ).state


                Box(
                    modifier = Modifier
                        .background(

                            brush = Brush.linearGradient(
                                colors = listOf(Color.White, Color(0xFF87CEEB)),
                                start = Offset(0f, 0f),
                                end = Offset(0f, Float.POSITIVE_INFINITY)
                            ),
                            shape = RoundedCornerShape(8.dp)
                        )
                        .padding(8.dp)
                        .wrapContentSize(Alignment.Center)
                ) {
                    Column(
                    )
                    {
                        if (imageState is AsyncImagePainter.State.Error) {
                            Box(
                                modifier = Modifier
                                    .fillMaxWidth()
                                    .height(200.dp),
                                contentAlignment = Alignment.Center
                            ) {
                                CircularProgressIndicator()
                            }
                        }

                        if (imageState is AsyncImagePainter.State.Success) {
                            Image(
                                modifier = Modifier
                                    .fillMaxWidth()
                                    .height(200.dp),
                                painter = imageState.painter,
                                contentDescription = "",
                                contentScale = ContentScale.Crop
                            )
                        }
                        Text(
                            "Название: ${song.title_song}",

                            modifier = Modifier.padding(8.dp),
                        )

                        val genreid = song.genre
                        val genre = genres.find { it.id == genreid }
                        if (genre != null) {
                            Text(
                                "Жанр песни:${genre.title}",
                                modifier = Modifier.padding(8.dp),
                            )
                        } else {
                            Text(
                                "Ошибка",
                                modifier = Modifier.padding(8.dp),
                            )
                        }
                        val performerid = song.performer
                        val performer = performers.find { it.id == performerid }
                        if (performer != null) {
                            Text(
                                "Автор:${performer.title}",
                                modifier = Modifier.padding(8.dp),
                            )

                        } else {
                            Text(
                                "Ошибка",
                                modifier = Modifier.padding(8.dp),
                            )
                        }


                    }
                }
                Spacer(modifier = Modifier.height(16.dp))

            }


        }
    }
}
